@@ -23,15 +23,15 @@ __all__ = [
 		]
 
 __copyright__ = """
-2020 Dominic Davis-Foster <dominic@davis-foster.co.uk>
+2020-2021 Dominic Davis-Foster <dominic@davis-foster.co.uk>
 """
 
-__version__ = "0.4.0"
+__version__ = "0.5.0"
 
 repo_root = pathlib.Path(__file__).parent
 install_requires = (repo_root / "requirements.txt").read_text(encoding="utf-8").split('\n')
 extras_require = {
-		'sphinx': ['sphinx', 'sphinx-toolbox', 'docutils'],
-		'testing': ['pytest'],
-		'all': ['docutils', 'pytest', 'sphinx', 'sphinx-toolbox']
+		"sphinx": ["sphinx<3.4.0,>=3.0.3", "sphinx-toolbox", "docutils"],
+		"testing": ["pytest"],
+		"all": ["docutils", "pytest", "sphinx-toolbox", "sphinx<3.4.0,>=3.0.3"]
 		}
