@@ -53,7 +53,7 @@ class ConfigVarMeta(type):
 	category: str
 	__name__: str
 
-	def __new__(cls, name: str, bases, dct: Dict):
+	def __new__(cls, name: str, bases, dct: Dict):  # noqa: D102
 		x = cast("ConfigVar", super().__new__(cls, name, bases, dct))
 
 		def get(name, default):
@@ -102,7 +102,7 @@ class ConfigVarMeta(type):
 			schema["required"].append(cls.__name__)
 
 		for line in (cls.__doc__ or '').split("\n\n"):
-			line = " ".join([p.strip() for p in line.split("\n") if p.strip()])
+			line = ' '.join([p.strip() for p in line.split('\n') if p.strip()])
 			if line:
 				schema["properties"][cls.__name__]["description"] = line
 				break
@@ -110,14 +110,14 @@ class ConfigVarMeta(type):
 		return schema
 
 	@property
-	def schema_entry(cls) -> Dict[str, Any]:
+	def schema_entry(cls) -> Dict[str, Any]:  # noqa: D102
 		return cls.get_schema_entry()
 
-	def __call__(cls, raw_config_vars: Dict[str, Any]) -> Any:  # type: ignore
+	def __call__(cls, raw_config_vars: Dict[str, Any]) -> Any:  # type: ignore  # noqa: D102
 		return cls.get(raw_config_vars)
 
 	@abstractmethod
-	def get(cls, raw_config_vars: Mapping[str, Any]):  # pragma: no cover
+	def get(cls, raw_config_vars: Mapping[str, Any]):  # pragma: no cover  # noqa: D102
 		return NotImplemented
 
 	def __repr__(self) -> str:
