@@ -38,7 +38,7 @@ from abc import ABC
 from typing import Any, Dict, List, Type
 
 # 3rd party
-import pytest
+import pytest  # nodep
 
 # this package
 from configconfig.configvar import ConfigVar
@@ -80,7 +80,7 @@ class NotIntTest(ConfigVarTest):
 	"""  # noqa: D400
 
 	def test_error_int(self):  # noqa: D102
-		with pytest.raises(ValueError):
+		with pytest.raises(ValueError):  # noqa: PT011
 			self.config_var.get({self.config_var.__name__: 1234})
 
 
@@ -91,7 +91,7 @@ class NotBoolTest(ConfigVarTest):
 	"""  # noqa: D400
 
 	def test_error_bool(self):  # noqa: D102
-		with pytest.raises(ValueError):
+		with pytest.raises(ValueError):  # noqa: PT011
 			self.config_var.get({self.config_var.__name__: True})
 
 
@@ -102,7 +102,7 @@ class NotStrTest(ConfigVarTest):
 	"""  # noqa: D400
 
 	def test_error_str(self):  # noqa: D102
-		with pytest.raises(ValueError):
+		with pytest.raises(ValueError):  # noqa: PT011
 			self.config_var.get({self.config_var.__name__: "a string"})
 
 
@@ -130,10 +130,6 @@ class ListTest(NotStrTest, NotBoolTest, NotIntTest, ConfigVarTest):
 		assert self.config_var.get() == self.default_value
 		assert self.config_var.get({}) == self.default_value
 
-	def test_error_list_int(self):  # noqa: D102
-		with pytest.raises(ValueError):
-			self.config_var.get({self.config_var.__name__: test_list_int})
-
 
 class DirectoryTest(NotBoolTest, NotIntTest, ConfigVarTest):
 	"""
@@ -159,11 +155,11 @@ class DirectoryTest(NotBoolTest, NotIntTest, ConfigVarTest):
 		assert self.config_var.get({}) == self.default_value
 
 	def test_error_list_int(self):  # noqa: D102
-		with pytest.raises(ValueError):
+		with pytest.raises(ValueError, match="'.*' must be a <class 'str'>"):  # noqa: PT011
 			self.config_var.get({self.config_var.__name__: test_list_int})
 
 	def test_error_list_str(self):  # noqa: D102
-		with pytest.raises(ValueError):
+		with pytest.raises(ValueError):  # noqa: PT011
 			self.config_var.get({self.config_var.__name__: test_list_str})
 
 
@@ -233,7 +229,7 @@ class BoolTrueTest(ConfigVarTest):
 
 	def test_errors(self):  # noqa: D102
 		for wrong_value in self.wrong_values:
-			with pytest.raises(ValueError):
+			with pytest.raises(ValueError):  # noqa: PT011
 				self.config_var.get(wrong_value)
 
 
@@ -249,7 +245,7 @@ class BoolFalseTest(BoolTrueTest):
 	"""
 
 	@property
-	def true_values(self) -> List[Dict[str, Any]]:
+	def true_values(self) -> List[Dict[str, Any]]:  # noqa: D102
 		return [
 				{self.config_var.__name__: True},
 				{self.config_var.__name__: 1},
@@ -259,7 +255,7 @@ class BoolFalseTest(BoolTrueTest):
 				]
 
 	@property
-	def false_values(self) -> List[Dict[str, Any]]:
+	def false_values(self) -> List[Dict[str, Any]]:  # noqa: D102
 		return [
 				{self.config_var.__name__: 0},
 				{self.config_var.__name__: False},
@@ -281,7 +277,7 @@ class RequiredStringTest(ConfigVarTest):
 	test_value: str
 
 	def test_empty_get(self):  # noqa: D102
-		with pytest.raises(ValueError):
+		with pytest.raises(ValueError):  # noqa: PT011
 			self.config_var.get()
 
 	def test_success(self):  # noqa: D102
@@ -302,7 +298,7 @@ class RequiredStringTest(ConfigVarTest):
 
 	def test_errors(self):  # noqa: D102
 		for wrong_value in self.wrong_values:
-			with pytest.raises(ValueError):
+			with pytest.raises(ValueError):  # noqa: PT011
 				self.config_var.get(wrong_value)
 
 
@@ -340,7 +336,7 @@ class OptionalStringTest(RequiredStringTest):
 
 	def test_errors(self):  # noqa: D102
 		for wrong_value in self.wrong_values:
-			with pytest.raises(ValueError):
+			with pytest.raises(ValueError):  # noqa: PT011
 				self.config_var.get(wrong_value)
 
 
@@ -361,7 +357,7 @@ class EnumTest(RequiredStringTest):
 
 	def test_non_enum(self):  # noqa: D102
 		for non_enum in self.non_enum_values:
-			with pytest.raises(ValueError):
+			with pytest.raises(ValueError):  # noqa: PT011
 				self.config_var.get({self.config_var.__name__: non_enum})
 
 	def test_errors(self):  # noqa: D102
@@ -372,7 +368,7 @@ class EnumTest(RequiredStringTest):
 				{self.config_var.__name__: test_list_str},
 				]
 		for wrong_value in wrong_values:
-			with pytest.raises(ValueError):
+			with pytest.raises(ValueError):  # noqa: PT011
 				self.config_var.get(wrong_value)
 
 
@@ -401,5 +397,5 @@ class DictTest(NotStrTest, NotBoolTest, NotIntTest, ConfigVarTest):
 		assert self.config_var.get({}) == self.default_value
 
 	def test_error_list_int(self):  # noqa: D102
-		with pytest.raises(ValueError):
+		with pytest.raises(ValueError):  # noqa: PT011
 			self.config_var.get({self.config_var.__name__: test_list_int})
