@@ -66,7 +66,9 @@ else:  # pragma: no cover (>=py38)
 		"""Get type arguments with all substitutions performed.
 
 		For unions, basic simplifications used by Union constructor are performed.
+
 		Examples::
+
 			get_args(Dict[str, int]) == (str, int)
 			get_args(int) == ()
 			get_args(Union[int, Union[T, int], str][int]) == (int, str)
@@ -90,10 +92,11 @@ __all__ = [
 		"check_union",
 		"get_json_type",
 		"tab",
+		"RawConfigVarsType",
 		]
 
 #: A literal ``TAB`` (``\t``) character for use in f-strings.
-tab = "\t"
+tab = '\t'
 
 if sys.version_info < (3, 7):
 	UnionType = Any
@@ -105,11 +108,13 @@ else:
 
 def optional_getter(raw_config_vars: Dict[str, Any], cls: "ConfigVarMeta", required: bool) -> Any:
 	"""
+	Returns either the configuration value, the default,
+	or raises an error if the value is required but wasn't supplied.
 
 	:param raw_config_vars:
 	:param cls:
 	:param required:
-	"""
+	"""  # noqa: D400
 
 	if required:
 		try:
@@ -229,14 +234,19 @@ def check_union(obj: Any, dtype: Union[GenericAliasType, UnionType]) -> bool:
 	:type dtype: :class:`~typing.Union`\, :class:`~typing.List`\, etc.
 	"""
 
-	return isinstance(obj, dtype.__args__)
+	args = dtype.__args__
+
+	if float in args and int not in args:
+		args = (*dtype.__args__, int)
+
+	return isinstance(obj, args)
 
 
 def get_json_type(type_: Type) -> Dict[str, Union[str, List, Dict]]:
-	"""
+	r"""
 	Get the type for the JSON schema that corresponds to the given Python type.
 
-	:param type_:
+	:param type\_:
 	"""
 
 	if type_ in json_type_lookup:
@@ -301,3 +311,6 @@ def get_literal_values(literal: Literal) -> typing.Tuple[Any]:  # type: ignore
 		return literal.__values__
 	else:
 		return literal.__args__
+
+
+RawConfigVarsType = Dict[str, Any]
